@@ -1,17 +1,13 @@
 from terra_sdk.core import AccAddress, Coins
 
-from ._base import BaseAPI
+from ._base import BaseAsyncAPI, sync_bind
+
+__all__ = ["AsyncBankAPI", "BankAPI"]
 
 
-class AsyncBankAPI(BaseAPI):
+class AsyncBankAPI(BaseAsyncAPI):
     async def balance(self, address: AccAddress) -> Coins:
-        res = await self._c._get(f"/bank/balances/{address}")
-        return Coins.from_data(res)
-
-
-class BankAPI(BaseAPI):
-    def balance(self, address: AccAddress) -> Coins:
-        """Fetches the current balance of an account.
+        """Fetches an account's current balance.
 
         Args:
             address (AccAddress): account address
@@ -19,5 +15,13 @@ class BankAPI(BaseAPI):
         Returns:
             Coins: balance
         """
-        res = self._c._get(f"/bank/balances/{address}")
+        res = await self._c._get(f"/bank/balances/{address}")
         return Coins.from_data(res)
+
+
+class BankAPI(AsyncBankAPI):
+    @sync_bind(AsyncBankAPI.balance)
+    def balance(self, address: AccAddress) -> Coins:
+        pass
+
+    balance.__doc__ = AsyncBankAPI.balance.__doc__
